@@ -1,40 +1,41 @@
 /*
     Copyright (c) 2010 Tobias Koenig <tokoe@kde.org>
 
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
+    This program is free software; you can redistribute it and/or modify it
+    under the terms of the GNU Library General Public License as published by
+    the Free Software Foundation; either version 2 of the License, or (at your
+    option) any later version.
 
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-    GNU General Public License for more details.
+    This program is distributed in the hope that it will be useful, but WITHOUT
+    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
+    License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+    along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
 
 #include "davitemslistjob.h"
+#include "davjobbase_p.h"
 
 #include "daverror.h"
-#include "davmanager.h"
-#include "davprotocolbase.h"
+#include "davmanager_p.h"
+#include "davprotocolbase_p.h"
 #include "davurl.h"
-#include "utils.h"
+#include "utils_p.h"
 #include "etagcache.h"
 
 #include <KIO/DavJob>
 #include <KIO/Job>
 
+#include <QSet>
+
 using namespace KDAV;
 
-class DavItemsListJobPrivate
+namespace KDAV {
+class DavItemsListJobPrivate : public DavJobBasePrivate
 {
 public:
-    DavItemsListJobPrivate(const DavUrl &url, const std::shared_ptr<EtagCache> &cache);
-
     DavUrl mUrl;
     std::shared_ptr<EtagCache> mEtagCache;
     QStringList mMimeTypes;
@@ -44,40 +45,37 @@ public:
     QSet<QString> mSeenUrls; // to prevent events duplication with some servers
     DavItem::List mChangedItems;
     QStringList mDeletedItems;
-    uint mSubJobCount;
+    uint mSubJobCount = 0;
 };
-
-DavItemsListJobPrivate::DavItemsListJobPrivate(const DavUrl &url, const std::shared_ptr<EtagCache> &cache)
-    : mUrl(url)
-    , mEtagCache(cache)
-    , mSubJobCount(0)
-{
 }
 
 DavItemsListJob::DavItemsListJob(const DavUrl &url, const std::shared_ptr<EtagCache> &cache, QObject *parent)
-    : DavJobBase(parent)
-    , d(std::unique_ptr<DavItemsListJobPrivate>(new DavItemsListJobPrivate(url, cache)))
+    : DavJobBase(new DavItemsListJobPrivate, parent)
 {
+    Q_D(DavItemsListJob);
+    d->mUrl = url;
+    d->mEtagCache = cache;
 }
 
-DavItemsListJob::~DavItemsListJob()
-{
-}
+DavItemsListJob::~DavItemsListJob() = default;
 
 void DavItemsListJob::setContentMimeTypes(const QStringList &types)
 {
+    Q_D(DavItemsListJob);
     d->mMimeTypes = types;
 }
 
 void DavItemsListJob::setTimeRange(const QString &start, const QString &end)
 {
+    Q_D(DavItemsListJob);
     d->mRangeStart = start;
     d->mRangeEnd = end;
 }
 
 void DavItemsListJob::start()
 {
-    const DavProtocolBase *protocol = DavManager::self()->davProtocol(d->mUrl.protocol());
+    Q_D(DavItemsListJob);
+    const DavProtocolBase *protocol = DavManager::davProtocol(d->mUrl.protocol());
     Q_ASSERT(protocol);
     QVectorIterator<XMLQueryBuilder::Ptr> it(protocol->itemsQueries());
 
@@ -120,21 +118,25 @@ void DavItemsListJob::start()
 
 DavItem::List DavItemsListJob::items() const
 {
+    Q_D(const DavItemsListJob);
     return d->mItems;
 }
 
 DavItem::List DavItemsListJob::changedItems() const
 {
+    Q_D(const DavItemsListJob);
     return d->mChangedItems;
 }
 
 QStringList DavItemsListJob::deletedItems() const
 {
+    Q_D(const DavItemsListJob);
     return d->mDeletedItems;
 }
 
 void DavItemsListJob::davJobFinished(KJob *job)
 {
+    Q_D(DavItemsListJob);
     KIO::DavJob *davJob = qobject_cast<KIO::DavJob *>(job);
     const int responseCode = davJob->queryMetaData(QStringLiteral("responsecode")).isEmpty()
                              ? 0
